==> haskell-src-meta-0.8.2-19-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-src-meta.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: haskell-src-meta
version: 0.8.2
id: haskell-src-meta-0.8.2-DORzvGt0MI4uppYtSMBiU
key: haskell-src-meta-0.8.2-DORzvGt0MI4uppYtSMBiU
license: BSD-3-Clause
copyright: (c) Matt Morrow
maintainer: danburton.email@gmail.com
author: Matt Morrow
synopsis: Parse source to template-haskell abstract syntax.
description:
    The translation from haskell-src-exts abstract syntax
    to template-haskell abstract syntax isn'\''t 100% complete yet.
category: Language, Template Haskell
abi: 2f8a7c11f502fedefac08354db5217a5
exposed: True
exposed-modules:
    Language.Haskell.Meta Language.Haskell.Meta.Parse
    Language.Haskell.Meta.Syntax.Translate Language.Haskell.Meta.Utils
import-dirs: /usr/lib/ghc-8.6.5/site-local/haskell-src-meta-0.8.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/haskell-src-meta-0.8.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/haskell-src-meta-0.8.2
hs-libraries: HShaskell-src-meta-0.8.2-DORzvGt0MI4uppYtSMBiU
depends:
    base-4.12.0.0 haskell-src-exts-1.21.0-mhcTUI6FEW8wbumxaToGl
    pretty-1.1.3.6 syb-0.7-KRW1LCxdMiCJrmhxCvzo37
    template-haskell-2.14.0.0 th-orphans-0.13.7-LArfYXkfrZ8K8laJxNSFUU
haddock-interfaces: /usr/share/doc/haskell-src-meta/html/haskell-src-meta.haddock
haddock-html: /usr/share/doc/haskell-src-meta/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-src-meta-0.8.2-21-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-src-meta.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: haskell-src-meta
version: 0.8.2
id: haskell-src-meta-0.8.2-7EvmDOz4E2IGpG7Bky61EY
key: haskell-src-meta-0.8.2-7EvmDOz4E2IGpG7Bky61EY
license: BSD-3-Clause
copyright: (c) Matt Morrow
maintainer: danburton.email@gmail.com
author: Matt Morrow
synopsis: Parse source to template-haskell abstract syntax.
description:
    The translation from haskell-src-exts abstract syntax
    to template-haskell abstract syntax isn'\''t 100% complete yet.
category: Language, Template Haskell
abi: 43e5bd59d0111b595a6c1a37d365025e
exposed: True
exposed-modules:
    Language.Haskell.Meta Language.Haskell.Meta.Parse
    Language.Haskell.Meta.Syntax.Translate Language.Haskell.Meta.Utils
import-dirs: /usr/lib/ghc-8.6.5/site-local/haskell-src-meta-0.8.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/haskell-src-meta-0.8.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/haskell-src-meta-0.8.2
hs-libraries: HShaskell-src-meta-0.8.2-7EvmDOz4E2IGpG7Bky61EY
depends:
    base-4.12.0.0 haskell-src-exts-1.21.0-mhcTUI6FEW8wbumxaToGl
    pretty-1.1.3.6 syb-0.7.1-1gO4OjQOULM8usUjWwwEyW
    template-haskell-2.14.0.0 th-orphans-0.13.7-DUJOkoalsVb5WsKzKaiJnm
haddock-interfaces: /usr/share/doc/haskell-src-meta/html/haskell-src-meta.haddock
haddock-html: /usr/share/doc/haskell-src-meta/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
